==> goreleaser-2.0.0.tar.gz: goreleaser-2.0.0/www/docs/sponsors.md <==
# Sponsors

Do you or your company use GoReleaser?
You can help keep the project bug-free and feature rich by sponsoring the
project and its maintainers.

## GitHub Sponsors

GitHub Sponsors is a great way to contribute directly to the GoReleaser
maintainer, [caarlos0](https://github.com/caarlos0).

This money usually goes to buying coffee, beer, better hardware, and, hopefully,
one day, paying the bills.

### High-tier sponsors:

<a href="https://smallstep.com" target="_blank"><img width="200" src="https://github.com/goreleaser/goreleaser/assets/245435/05ade839-6652-474a-af90-da3ea67dde24"></a>

### Add yourself or your company to the list

You can sponsor and see who's sponsoring Carlos [here](https://github.com/sponsors/caarlos0).

<iframe src="https://github.com/sponsors/caarlos0/button" title="Sponsor caarlos0" height="35" width="116" style="border: 0;"></iframe>

And, of course, you can also sponsor any of
[contributors](https://github.com/orgs/goreleaser/people) in whatever way they
prefer it!

## OpenCollective

OpenCollective is a great way to send some money towards the GoReleaser
organization.

This ultimately is used to buy/renew domains, keep servers up, print and send
stickers to contributors and users, among other things.

You can start sponsoring at the [OpenCollective
website](https://opencollective.com/goreleaser).

Below you can see a list of the current sponsors and backers on OpenCollective:

<script src="https://opencollective.com/goreleaser/banner.js"></script>

---

**✨✨ Thanks for your support! ✨✨**

==> goreleaser-2.8.1.tar.gz: goreleaser-2.8.1/www/docs/sponsors.md <==
# Sponsors

Do you or your company use GoReleaser?
You can help keep the project bug-free and feature rich by sponsoring the
project and its maintainers.

## GitHub Sponsors

GitHub Sponsors is a great way to contribute directly to the GoReleaser
maintainer, [caarlos0](https://github.com/caarlos0).

This money usually goes to buying coffee, beer, better hardware, and, hopefully,
one day, paying the bills.

### High-tier sponsors

<a href="https://smallstep.com" target="_blank"><img width="200" src="https://github.com/goreleaser/goreleaser/assets/245435/05ade839-6652-474a-af90-da3ea67dde24"></a>

### Add yourself or your company to the list

You can sponsor and see who's sponsoring Carlos [here](https://github.com/sponsors/caarlos0).

<iframe src="https://github.com/sponsors/caarlos0/button" title="Sponsor caarlos0" height="35" width="116" style="border: 0;"></iframe>

And, of course, you can also sponsor any of
[contributors](https://github.com/orgs/goreleaser/people) in whatever way they
prefer it!

## OpenCollective

OpenCollective is a great way to send some money towards the GoReleaser
organization.

This ultimately is used to buy/renew domains, keep servers up, print and send
stickers to contributors and users, among other things.

You can start sponsoring at the
[OpenCollective website](https://opencollective.com/goreleaser).

Below you can see a list of the current sponsors and backers on OpenCollective:

<script src="https://opencollective.com/goreleaser/banner.js"></script>

---

**✨✨ Thanks for your support! ✨✨**
